summaryrefslogtreecommitdiffstats
path: root/kmymoney2/views/kscheduledlistitem.h
diff options
context:
space:
mode:
Diffstat (limited to 'kmymoney2/views/kscheduledlistitem.h')
-rw-r--r--kmymoney2/views/kscheduledlistitem.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/kmymoney2/views/kscheduledlistitem.h b/kmymoney2/views/kscheduledlistitem.h
index 62df861..44d2af8 100644
--- a/kmymoney2/views/kscheduledlistitem.h
+++ b/kmymoney2/views/kscheduledlistitem.h
@@ -56,14 +56,14 @@ public:
*
* Other types may be added in the future.
*
* @param tqparent The list view to be a child of.
* @param description The (translated) description.
* @param pixmap A pixmap for the entry
* @param sortKey a sortkey, if empty, @c description will be used.
*
* @see MyMoneySchedule
*/
- KScheduledListItem(KListView *tqparent, const TQString& description, const TQPixmap& pixmap = TQPixmap(), const TQString& sortKey = TQString());
+ KScheduledListItem(KListView *parent, const TQString& description, const TQPixmap& pixmap = TQPixmap(), const TQString& sortKey = TQString());
/**
* This constructor is used to create a child of one of the tqchildren
@@ -71,12 +71,12 @@ public:
*
* This child describes a schedule and represents the data in schedule.
*
* @param tqparent The list view item to be a child of.
* @param schedule The schedule to be represented.
*
* @see MyMoneySchedule
*/
- KScheduledListItem(KScheduledListItem *tqparent, const MyMoneySchedule& schedule/*, bool even*/);
+ KScheduledListItem(KScheduledListItem *parent, const MyMoneySchedule& schedule/*, bool even*/);
/**
* Standard destructor.
@@ -56,14 +56,14 @@ public:
* Other types may be added in the future.
*
- * @param tqparent The list view to be a child of.
+ * @param parent The list view to be a child of.
* @param description The (translated) description.
* @param pixmap A pixmap for the entry
@@ -71,12 +71,12 @@ public:
* This child describes a schedule and represents the data in schedule.
*
- * @param tqparent The list view item to be a child of.
+ * @param parent The list view item to be a child of.
* @param schedule The schedule to be represented.
*